OC.L10N.register(
    "core",
    {
    "File is too big" : "فایل خیلی بزرگ است",
    "Invalid file provided" : "فایل داده‌شده نا معتبر است",
    "No image or file provided" : "هیچ فایل یا تصویری وارد نشده است",
    "Unknown filetype" : "نوع فایل ناشناخته",
    "Invalid image" : "عکس نامعتبر",
    "An error occurred. Please contact your admin." : "یک خطا رخ داده است. لطفا با مدیر سیستم تماس بگیرید.",
    "No temporary profile picture available, try again" : "تصویر پروفایل موقت در حال حاضر در دسترس نیست ، دوباره تلاش کنید ",
    "Crop is not square" : "بخش بریده شده مربع نیست",
    "%s password reset" : "%s رمزعبور تغییر کرد",
    "Couldn't send reset email. Please contact your administrator." : "ارسال ایمیل مجدد با مشکل مواجه شد . لطفا با مدیر سیستم تماس بگیرید .",
    "Preparing update" : "آماده‌سازی به روز‌ رسانی",
    "Repair warning: " : "اخطار تعمیر:",
    "Repair error: " : "خطای تعمیر:",
    "Turned off maintenance mode" : "حالت \" در دست تعمیر \" غیرفعال شد .",
    "Maintenance mode is kept active" : "حالت تعمیرات فعال نگه‌داشته شده است",
    "Updated database" : "بروز رسانی پایگاه داده انجام شد .",
    "Updated \"%s\" to %s" : "\"%s\" به %s بروزرسانی شد",
    "Already up to date" : "در حال حاضر بروز است",
    "Sunday" : "یکشنبه",
    "Monday" : "دوشنبه",
    "Tuesday" : "سه شنبه",
    "Wednesday" : "چهارشنبه",
    "Thursday" : "پنجشنبه",
    "Friday" : "جمعه",
    "Saturday" : "شنبه",
    "Sun." : "یکشنبه",
    "Mon." : "دوشنبه",
    "Tue." : "سه شنبه",
    "Wed." : "چهارشنبه",
    "Thu." : "پنج شنبه",
    "Fri." : "جمعه",
    "Sat." : "شنبه",
    "Su" : "یک‌شنبه",
    "Mo" : "دوشنبه",
    "Tu" : "سه‌شنبه",
    "We" : "چهار‌شنبه",
    "Th" : "پنج‌شنبه",
    "Fr" : "جمعه",
    "Sa" : "شنبه",
    "January" : "ژانویه",
    "February" : "فبریه",
    "March" : "مارس",
    "April" : "آوریل",
    "May" : "می",
    "June" : "ژوئن",
    "July" : "جولای",
    "August" : "آگوست",
    "September" : "سپتامبر",
    "October" : "اکتبر",
    "November" : "نوامبر",
    "December" : "دسامبر",
    "Jan." : "ژانویه",
    "Feb." : "فوریه",
    "Mar." : "مارچ",
    "Apr." : "آوریل",
    "May." : "می",
    "Jun." : "ژوئن",
    "Jul." : "جولای",
    "Aug." : "آگوست",
    "Sep." : "سپتامبر",
    "Oct." : "اکتبر",
    "Nov." : "نوامبر",
    "Dec." : "دسامبر",
    "Settings" : "تنظیمات",
    "Saving..." : "در حال ذخیره سازی...",
    "Dismiss" : "پنهان کن",
    "seconds ago" : "ثانیه‌ها پیش",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "لینک تنظیم مجدد رمز عبور به ایمیل شما ارسال شده است.<br>اگر آن رادر یک زمان مشخصی دریافت نکرده اید، لطفا هرزنامه/ پوشه های ناخواسته را بررسی کنید.<br>در صورت نبودن از مدیر خود بپرسید.",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "فایل های شما رمزگذاری شده اند. اگر شما کلید بازیابی را فعال نکرده اید، پس از راه اندازی مجدد رمزعبور هیچ راهی برای بازگشت اطلاعاتتان وجود نخواهد داشت.در صورت عدم اطمینان به انجام کار، لطفا ابتدا با مدیر خود تماس بگیرید. آیا واقعا میخواهید ادامه دهید ؟",
    "I know what I'm doing" : "اطلاع از انجام این کار دارم",
    "Password can not be changed. Please contact your administrator." : "رمز عبور نمی تواند تغییر بکند . لطفا با مدیر سیستم تماس بگیرید .",
    "No" : "نه",
    "Yes" : "بله",
    "Choose" : "انتخاب کردن",
    "Error loading file picker template: {error}" : "خطا در بارگذاری قالب انتخاب فایل : {error}",
    "Ok" : "قبول",
    "Error loading message template: {error}" : "خطا در بارگذاری قالب پیام : {error}",
    "read-only" : "فقط-خواندنی",
    "One file conflict" : "یک فایل متضاد",
    "New Files" : "فایل های جدید",
    "Already existing files" : "فایل های موجود در حال حاضر ",
    "Which files do you want to keep?" : "کدام فایل ها را می خواهید نگه دارید ؟",
    "Cancel" : "منصرف شدن",
    "Continue" : "ادامه",
    "(all selected)" : "(همه انتخاب شده اند)",
    "({count} selected)" : "({count} انتخاب شده)",
    "Error loading file exists template" : "خطا در بارگزاری فایل قالب",
    "Very weak password" : "رمز عبور بسیار ضعیف",
    "Weak password" : "رمز عبور ضعیف",
    "So-so password" : "رمز عبور متوسط",
    "Good password" : "رمز عبور خوب",
    "Strong password" : "رمز عبور قوی",
    "Error occurred while checking server setup" : "خطا در هنگام چک کردن راه‌اندازی سرور رخ داده است",
    "Shared" : "اشتراک گذاشته شده",
    "Shared with {recipients}" : "به اشتراک گذاشته شده با {recipients}",
    "Error" : "خطا",
    "Error while sharing" : "خطا درحال به اشتراک گذاشتن",
    "Error while unsharing" : "خطا درحال لغو اشتراک",
    "The public link will expire no later than {days} days after it is created" : "لینک عمومی پس از {days} روز پس از ایجاد منقضی خواهد شد",
    "Set expiration date" : "تنظیم تاریخ انقضا",
    "Expiration" : "تاریخ انقضا",
    "Expiration date" : "تاریخ انقضا",
    "Link" : "لینک",
    "Edit" : "ویرایش",
    "Remove" : "برداشتن",
    "Choose a password for the public link" : "انتخاب رمز برای لینک عمومی",
    "Filename" : "نام فایل",
    "Password" : "گذرواژه",
    "Name" : "نام",
    "Allow editing" : "اجازه‌ی ویرایش",
    "Save" : "ذخیره",
    "Error while sending notification" : "خطا در حین ارسال نوتیفیکیشن",
    "Sending ..." : "درحال ارسال ...",
    "Email sent" : "ایمیل ارسال شد",
    "Email link to person" : "پیوند ایمیل برای شخص.",
    "Shared with you and the group {group} by {owner}" : "به اشتراک گذاشته شده با شما و گروه {گروه} توسط {دارنده}",
    "Shared with you by {owner}" : "به اشتراک گذاشته شده با شما توسط { دارنده}",
    "group" : "گروه",
    "remote" : "از راه دور",
    "notify by email" : "دریافت هشدار از طریق ایمیل",
    "Unshare" : "لغو اشتراک",
    "can share" : "قابل به اشتراک گذاری",
    "can edit" : "می توان ویرایش کرد",
    "create" : "ایجاد",
    "change" : "تغییر",
    "delete" : "پاک کردن",
    "access control" : "کنترل دسترسی",
    "Share" : "اشتراک‌گذاری",
    "Resharing is not allowed" : "اشتراک گذاری مجدد مجاز نمی باشد",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "اشتراک‌گذاری با دیگر افراد بر روی ownClouds بصورت username@example.com/owncloud",
    "Warning" : "اخطار",
    "Delete" : "حذف",
    "Rename" : "تغییرنام",
    "The object type is not specified." : "نوع شی تعیین نشده است.",
    "Enter new" : "مورد جدید را وارد کنید",
    "Add" : "افزودن",
    "Edit tags" : "ویرایش تگ ها",
    "No tags selected for deletion." : "هیچ تگی برای حذف انتخاب نشده است.",
    "unknown text" : "متن نامعلوم",
    "Hello world!" : "سلام دنیا!",
    "sunny" : "آفتابی",
    "Hello {name}, the weather is {weather}" : "سلام {name}, هوا  {weather} است",
    "Hello {name}" : "سلام {name}",
    "_download %n file_::_download %n files_" : ["دانلود %n فایل"],
    "An error occurred." : "یک خطا رخ‌داده است.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "به روز رسانی ناموفق بود. لطفا این خطا را به  <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">جامعه ی OwnCloud</a> گزارش نمایید.",
    "The update was successful. There were warnings." : "بروزرسانی با موفقیت انجام شد، اخطارهایی وجود دارد.",
    "The update was successful. Redirecting you to ownCloud now." : "به روزرسانی موفقیت آمیز بود. در حال انتقال شما به OwnCloud.",
    "Searching other places" : "جستجو در مکان‌های دیگر",
    "Personal" : "شخصی",
    "Users" : "کاربران",
    "Apps" : "  برنامه ها",
    "Admin" : "مدیر",
    "Help" : "راه‌نما",
    "Access forbidden" : "اجازه دسترسی به مناطق ممنوعه را ندارید",
    "File not found" : "فایل یافت نشد",
    "The specified document has not been found on the server." : "مستند مورد نظر در سرور یافت نشد.",
    "You can click here to return to %s." : "شما می‎توانید برای بازگشت به  %s اینجا کلیک کنید.",
    "The share will expire on %s." : "اشتراک‌گذاری در %s منقضی خواهد شد.",
    "Cheers!" : "سلامتی!",
    "Internal Server Error" : "خطای داخلی سرور",
    "More details can be found in the server log." : "جزئیات بیشتر در لاگ سرور قابل مشاهده خواهد بود.",
    "Technical details" : "جزئیات فنی",
    "Remote Address: %s" : "آدرس راه‌دور: %s",
    "Request ID: %s" : "ID درخواست: %s",
    "Type: %s" : "نوع: %s",
    "Code: %s" : "کد: %s",
    "Message: %s" : "پیام: %s",
    "File: %s" : "فایل : %s",
    "Line: %s" : "خط: %s",
    "Create an <strong>admin account</strong>" : "لطفا یک <strong> شناسه برای مدیر</strong> بسازید",
    "Username" : "نام کاربری",
    "Storage & database" : "انبارش و پایگاه داده",
    "Data folder" : "پوشه اطلاعاتی",
    "Configure the database" : "پایگاه داده برنامه ریزی شدند",
    "Only %s is available." : "تنها %s موجود است.",
    "Install and activate additional PHP modules to choose other database types." : "جهت انتخاب انواع دیگر پایگاه‌داده‌،ماژول‌های اضافی PHP را نصب و فعال‌سازی کنید.",
    "For more details check out the documentation." : "برای جزئیات بیشتر به مستندات مراجعه کنید.",
    "Database user" : "شناسه پایگاه داده",
    "Database password" : "پسورد پایگاه داده",
    "Database name" : "نام پایگاه داده",
    "Database tablespace" : "جدول پایگاه داده",
    "Database host" : "هاست پایگاه داده",
    "Performance warning" : "اخطار کارایی",
    "SQLite will be used as database." : "SQLite به عنوان پایگاه‎داده استفاده خواهد شد.",
    "Finish setup" : "اتمام نصب",
    "Finishing …" : "در حال اتمام ...",
    "Need help?" : "کمک لازم دارید ؟",
    "See the documentation" : "مشاهده‌ی مستندات",
    "Log out" : "خروج",
    "Search" : "جست‌و‌جو",
    "Please contact your administrator." : "لطفا با مدیر وب‌سایت تماس بگیرید.",
    "Please try again or contact your administrator." : "لطفا مجددا تلاش کنید یا با مدیر سیستم تماس بگیرید.",
    "Log in" : "ورود",
    "Alternative Logins" : "ورود متناوب",
    "Use the following link to reset your password: {link}" : "از لینک زیر جهت دوباره سازی پسورد استفاده کنید :\n{link}",
    "New password" : "گذرواژه جدید",
    "New Password" : "رمزعبور جدید",
    "Reset password" : "تنظیم مجدد رمز عبور",
    "Thank you for your patience." : "از صبر شما متشکریم",
    "Add \"%s\" as trusted domain" : "افزودن \"%s\" به عنوان دامنه مورد اعتماد",
    "App update required" : "نیاز به بروزرسانی برنامه وجود دارد",
    "%s will be updated to version %s" : "%s به نسخه‌ی %s بروزرسانی خواهد شد",
    "These apps will be updated:" : "این برنامه‌ها بروزرسانی شده‌اند:",
    "The theme %s has been disabled." : "قالب %s غیر فعال شد.",
    "Start update" : "اغاز به روز رسانی"
},
"nplurals=1; plural=0;");
